# TEKLIB Package

A "dumping ground" for python functions and classes used in the analysis of marine systems.

## Installing TEKLIB

To install TEKLIB, first run the command

```sh
python -m pip install teklib # To install latest version
# OR
python -m pip install teklib==<version nr> # To install a specific version
```
